==> openmsghard-1.0.1.tar.gz: openmsghard-1.0.1/recvfile.c <==
#include "common.h"
#include "recvfile.h"

#define MAX_BUF 1024
#define DATA_BUF 2049
#define MAX_PATH 2048

void ready_recv() {
        printf("start ready_recv()\n");
        msn_session *session;
        int sock= dup(*file_queue[0].sendsock);;

        //sendsock = file_queue[0].sendsock;
        //recvsock = file_queue[0].recvsock;
        char send_buf[MAX_BUF];
        char recv_buf[MAX_BUF];
        char message[MAX_BUF];
        char *msn_tok[32];
        memset(msn_tok,0x0,sizeof(msn_tok));
        memset(message,0x0,MAX_BUF);
        memset(send_buf,0x0,MAX_BUF);
        memset(recv_buf,0x0,MAX_BUF);
        char *tmp_info[255];
        char present_path[MAX_PATH];
        char filename[256];
        memset(filename,0x0,sizeof(filename));
        char *filename_ptr;
        long filesize=0;
        char guid[40];
        char *tmp_buf[2];
        char *tmp_buf2[2];
        char old_name[256];
        char new_name[256];
        char recv_name[256];
        char *rename_tok[256]={'\0',};

        memset(old_name,0x0,sizeof(old_name));
        memset(new_name,0x0,sizeof(new_name));
        memset(recv_name,0x0,sizeof(recv_name));
        memset(rename_tok,0x0,sizeof(rename_tok));
        //printf("check point 1\n");
        list_file *p;
        p=file_queue[0].head;
        while(p=p->Next) {
                //printf("check %s\n",p->data.filename);
        }
        strncpy(old_name,file_queue[0].filename,strlen(file_queue[0].filename));
        memset(file_queue[0].filename,0x0,sizeof(file_queue[0].filename));
       // printf("old_name : %s\n",old_name);
       // printf("check point 2\n");
        file_rename(old_name,new_name,recv_name,rename_tok);
        //printf("check point 3\n");
	//printf("%s , %s\n",old_name,new_name);

        strncpy(file_queue[0].filename,new_name,strlen(new_name));
        char *ip="221.154.82.210";

        int i;
        int flag=1;
        long authcookie;
        srand(time(NULL));

        while(flag==1) {
        flag =0;
        authcookie = rand()%1000000;
        printf("authcookie : %ld\n",authcookie);

        for(i=0;i<=queue_ptr;i++) {
                if(authcookie==file_queue[i].authcookie) {
                        printf("Űߺ\n");
                        flag = 1;
                }
        }

        }

        //printf("check point 4\n");
	int port = 8080;
        snprintf(message,MAX_BUF,"MIME-Version: 1.0\r\nContent-Type: text/x-msmsgsinvite; charset=UTF-8\r\n\r\nRequest-Data: IP-Address:\r\nLaunch-Application: FALSE\r\nAuthCookie: %ld\r\nInvitation-Command: ACCEPT\r\nSender-Connect: TRUE\r\nIP-Address: %s\r\nInvitation-Cookie: %ld\r\nPort: %d\r\n\r\n\r\n",authcookie,ip,file_queue[0].cookie,port);

        snprintf(send_buf,MAX_BUF,"MSG %d N %d\r\n%s",0,strlen(message),message);

        //printf("\nfileanme : %s\n",file_queue[0].filename);

        if(send(sock,send_buf,strlen(send_buf),0)==-1) {
                   error_handling("send() error!!");
        }

        //printf("%s\n",send_buf);



        strncpy(file_queue[0].ip,ip,strlen(ip));
        file_queue[0].port = port;
        file_queue[0].authcookie=authcookie;




}

void start_recv(list_file *head,int *data_sock) {
        int fd;
        char openfile[strlen(file_queue[0].path)+strlen(file_queue[0].filename)+4];
        printf("ú path : %s/%s\n",file_queue[0].path,file_queue[0].filename);
        snprintf(openfile,sizeof(openfile),"%s/%s",file_queue[0].path,file_queue[0].filename);
        fd=open(openfile,O_WRONLY|O_CREAT|O_TRUNC,0700);

        if(fd==-1) error_handling("File open error");

        int filesize;
        int recv_len = 0;
        int recv_num = 0;
        int data_len = 0;
        int count=0;
        char data_recv_buf[DATA_BUF];
	char dis_buf[3];
	memset(dis_buf,0x0,3);
	dis_buf[0] = (char)1;
	dis_buf[1] = (char)253;
	dis_buf[2] = (char)7;
        memset(data_recv_buf,0x0,DATA_BUF);
        while(data_len < file_queue[0].filesize) {
                recv_len=0;
                recv_num=0;
                memset(data_recv_buf,0x0,DATA_BUF);


                for(recv_len=0;recv_len < DATA_BUF-1 && recv_len < file_queue[0].filesize;) {

                        recv_num = recv(*data_sock,&data_recv_buf[recv_len],(DATA_BUF-1)-recv_len,0);


                        if(recv_num == -1) {
                                error_handling("data recv() error!!");
                        }
                        //printf("%s\n",data_recv_buf);
                        recv_len+=recv_num;
                        data_len+=recv_num;
                        //printf("recv_len %d , recv_num %d\n",recv_len,recv_num);                        //memset(data_recv_buf,0x0,DATA_BUF);
                        recv_num=0;
                        count++;
                        //printf("data_len` : %d\n",data_len);
                        if((data_len-3)==file_queue[0].filesize) {
                                break;
                        }
		}


                if(strncmp(data_recv_buf,dis_buf,3)== 0) {
                        break;
                }
                write(fd,&data_recv_buf[3],recv_len-3);
                data_len-=3;
                //data_len+=recv_len;
                recv_len=0;
                //printf("filesize : %ld ,  data_len %d , recv_len %d\n",file_queue[0].filesize,data_len,recv_len);
                //printf("%d\n",strlen(data_recv_buf));
                //recv_len+=2048;
                //printf("queue : %ld , len : %ld\n",file_queue[queue_ptr].filesize,recv_len);
                count++;



        
	}
//fcntl(*data_sock, F_SETFL, 1);
        if(data_len == file_queue[0].filesize && dn_flag==0) {
                printf("recv success\n");
                recv_success(data_sock);

        }
        else {
                printf("recv failed\n");
		/*  ޾ұ⶧  */		
		char remove_buf[MAX_PATH];
		memset(remove_buf,0x0,MAX_PATH);
		snprintf(remove_buf,MAX_PATH,"rm -rf %s/%s",file_queue[0].path,file_queue[0].filename);
		//printf("%s\n",remove_buf);
		system(remove_buf);

                recv_failed(data_sock);
        }
        dn_flag = 0;
/* 뿡 ٹ޾ѱ⶧ ο ȭ  */
	printf(":::file_queue : %d :::\n",queue_ptr);
	delete_all(pub_head,pub_max_count);
	list_file *p=NULL;
	int max_count=0; 
	memset(pub_present_path,0x0,MAX_PATH);
	strncpy(pub_present_path,file_queue[0].path,strlen(file_queue[0].path));

     	pub_head=get_list_file(pub_present_path,&pub_max_count);
	pub_file_ptr=1;

        char format[80]="X-MMS-IM-Format: FN=%EA%B5%B4%EB%A6%BC%EC%B2%B4; EF=; CO=0; CS=81; PF=0";
        char format_ret[80];
	char u_send_buf[1500];
	char u_send_buf1[MAX_BUF];
	char *u_send_ptr1=NULL;
	memset(u_send_buf,0x0,MAX_BUF);
	memset(u_send_buf1,0x0,MAX_BUF);	
        url_encode(format, format_ret, strlen(format_ret));

	p=pub_head;


        set_send_message(pub_session,pub_head,u_send_buf,u_send_buf1,u_send_ptr1,pub_max_count,pub_file_ptr,pub_present_path,pub_print,format);
	//printf("after set_send_message , pahtred\n");
	p=pub_head;
        while(p=p->Next) {
                p->data.filename[strlen(p->data.filename)]='\0';
        }

        p=pub_head;

	//printf("%s\n",u_send_buf);

        if(send(*file_queue[0].sendsock,u_send_buf,strlen(u_send_buf),0)==-1)
        {
                 error_handling("cm_sendsock error!!");
        }

        if(send(*file_queue[0].sendsock,u_send_buf1,strlen(u_send_buf1),0)==-1)
        {
                 error_handling("cm_sendsock error!!");
        }


	pub_tree_ptr = file_queue[0].tree_ptr;


/* -----------------------------------------*/
        //order_queue(0,file_queue[0].cookie);
        //printf("\n%s\n",data_recv_buf);

        /*    */

        printf("recv_ended\n");
}



void recv_success(int *data_sock) {
        char buf[MAX_BUF];
        memset(buf,0x0,MAX_BUF);

        snprintf(buf,MAX_BUF,"BYE 16777989\r\n");
	db_insert_file(&conn,user_id);

        if(send(*data_sock,buf,strlen(buf),0)==-1) {
                   error_handling("BYE recv success send() error!!");
        }

}
void recv_failed(int *data_sock) {
        char buf[MAX_BUF];
        memset(buf,0x0,MAX_BUF);

        snprintf(buf,MAX_BUF,"BYE 2164261683\r\n");

        if(send(*data_sock,buf,strlen(buf),0)==-1) {
                   error_handling("BYE recv failed send() error!!");
        }

}

==> openmsghard-1.0.3.tar.gz: openmsghard-1.0.3/recvfile.c <==
#include "common.h"
#include "recvfile.h"

#define MAX_BUF 1024
#define DATA_BUF 2049
#define MAX_PATH 2048

void ready_recv() {
        printf("start ready_recv()\n");
        msn_session *session;
        int sock= dup(*file_queue[0].sendsock);;

        //sendsock = file_queue[0].sendsock;
        //recvsock = file_queue[0].recvsock;
        char send_buf[MAX_BUF];
        char recv_buf[MAX_BUF];
        char message[MAX_BUF];
        char *msn_tok[32];
        memset(msn_tok,0x0,sizeof(msn_tok));
        memset(message,0x0,MAX_BUF);
        memset(send_buf,0x0,MAX_BUF);
        memset(recv_buf,0x0,MAX_BUF);
        char *tmp_info[255];
        char present_path[MAX_PATH];
        char filename[256];
        memset(filename,0x0,sizeof(filename));
        char *filename_ptr;
        long filesize=0;
        char guid[40];
        char *tmp_buf[2];
        char *tmp_buf2[2];
        char old_name[256];
        char new_name[256];
        char recv_name[256];
        char *rename_tok[256]={'\0',};

        memset(old_name,0x0,sizeof(old_name));
        memset(new_name,0x0,sizeof(new_name));
        memset(recv_name,0x0,sizeof(recv_name));
        memset(rename_tok,0x0,sizeof(rename_tok));
        //printf("check point 1\n");
        list_file *p;
        p=file_queue[0].head;
        while(p=p->Next) {
                //printf("check %s\n",p->data.filename);
        }
        strncpy(old_name,file_queue[0].filename,strlen(file_queue[0].filename));
        memset(file_queue[0].filename,0x0,sizeof(file_queue[0].filename));
       // printf("old_name : %s\n",old_name);
       // printf("check point 2\n");
        file_rename(old_name,new_name,recv_name,rename_tok);
        //printf("check point 3\n");
	//printf("%s , %s\n",old_name,new_name);

        strncpy(file_queue[0].filename,new_name,strlen(new_name));
        char ip[32];
	memset(ip,0x0,32);
	strncpy(ip,conf.ip,strlen(conf.ip));

        int i;
        int flag=1;
        long authcookie;
        srand(time(NULL));

        while(flag==1) {
        flag =0;
        authcookie = rand()%1000000;
        //printf("authcookie : %ld\n",authcookie);

        for(i=0;i<=queue_ptr;i++) {
                if(authcookie==file_queue[i].authcookie) {
                        printf("Űߺ\n");
                        flag = 1;
                }
        }

        }

        //printf("check point 4\n");
	int port = 8080;
        snprintf(message,MAX_BUF,"MIME-Version: 1.0\r\nContent-Type: text/x-msmsgsinvite; charset=UTF-8\r\n\r\nRequest-Data: IP-Address:\r\nLaunch-Application: FALSE\r\nAuthCookie: %ld\r\nInvitation-Command: ACCEPT\r\nSender-Connect: TRUE\r\nIP-Address: %s\r\nInvitation-Cookie: %ld\r\nPort: %d\r\n\r\n\r\n",authcookie,ip,file_queue[0].cookie,port);

        snprintf(send_buf,MAX_BUF,"MSG %d N %d\r\n%s",0,strlen(message),message);

        //printf("\nfileanme : %s\n",file_queue[0].filename);

        if(send(sock,send_buf,strlen(send_buf),0)==-1) {
                   error_handling("send() error!!");
        }

        //printf("%s\n",send_buf);



        strncpy(file_queue[0].ip,ip,strlen(ip));
        file_queue[0].port = port;
        file_queue[0].authcookie=authcookie;




}

void start_recv(list_file *head,int *data_sock) {
        int fd;
        char openfile[strlen(file_queue[0].path)+strlen(file_queue[0].filename)+4];
        printf("ú path : %s/%s\n",file_queue[0].path,file_queue[0].filename);
        snprintf(openfile,sizeof(openfile),"%s/%s",file_queue[0].path,file_queue[0].filename);
//	printf("start1\n");
        fd=open(openfile,O_WRONLY|O_CREAT|O_TRUNC,0700);

        if(fd==-1) error_handling("File open error");
//	printf("start2\n");
        int filesize;
        int recv_len = 0;
        int recv_num = 0;
        int data_len = 0;
        int count=0;
        char data_recv_buf[DATA_BUF];
	char dis_buf[3];
	memset(dis_buf,0x0,3);
	dis_buf[0] = (char)1;
	dis_buf[1] = (char)253;
	dis_buf[2] = (char)7;
//	printf("start3\n");
        memset(data_recv_buf,0x0,DATA_BUF);
        while(data_len < file_queue[0].filesize) {
		//printf("in while\n");
                recv_len=0;
                recv_num=0;
                memset(data_recv_buf,0x0,DATA_BUF);


                for(recv_len=0;recv_len < DATA_BUF-1 && recv_len < file_queue[0].filesize;) {
			//printf("start5\n");
                        recv_num = recv(*data_sock,&data_recv_buf[recv_len],(DATA_BUF-1)-recv_len,0);
			//printf("start6\n");

                        if(recv_num == -1) {
                                error_handling("data recv() error!!");
                        }
                        //printf("%s\n",data_recv_buf);
                        recv_len+=recv_num;
                        data_len+=recv_num;
                        //printf("recv_len %d , recv_num %d\n",recv_len,recv_num);                        //memset(data_recv_buf,0x0,DATA_BUF);
                        recv_num=0;
                        count++;
                        //printf("data_len` : %d\n",data_len);
                        if((data_len-3)==file_queue[0].filesize) {
                                break;
                        }
		}


                if(strncmp(data_recv_buf,dis_buf,3)== 0) {
                        break;
                }
                write(fd,&data_recv_buf[3],recv_len-3);
                data_len-=3;
                //data_len+=recv_len;
                recv_len=0;
                //printf("filesize : %ld ,  data_len %d , recv_len %d\n",file_queue[0].filesize,data_len,recv_len);
                //printf("%d\n",strlen(data_recv_buf));
                //recv_len+=2048;
                //printf("queue : %ld , len : %ld\n",file_queue[queue_ptr].filesize,recv_len);
                count++;



        
	}
//fcntl(*data_sock, F_SETFL, 1);
        if(data_len == file_queue[0].filesize && dn_flag==0) {
                printf("recv success\n");
                recv_success(data_sock);

        }
        else {
                printf("recv failed\n");
		/*  ޾ұ⶧  */		
		char remove_buf[MAX_PATH];
		memset(remove_buf,0x0,MAX_PATH);
		snprintf(remove_buf,MAX_PATH,"rm -rf %s/%s",file_queue[0].path,file_queue[0].filename);
		//printf("%s\n",remove_buf);
		system(remove_buf);

                recv_failed(data_sock);
        }
        dn_flag = 0;
/* 뿡 ٹ޾ѱ⶧ ο ȭ  */

/*
	delete_all(pub_head,pub_max_count);
	list_file *p=NULL;
	int max_count=0; 
	memset(pub_present_path,0x0,MAX_PATH);
	strncpy(pub_present_path,file_queue[0].path,strlen(file_queue[0].path));

     	pub_head=get_list_file(pub_present_path,&pub_max_count);
	pub_file_ptr=1;

        char format[80]="X-MMS-IM-Format: FN=%EA%B5%B4%EB%A6%BC%EC%B2%B4; EF=; CO=0; CS=81; PF=0";
        char format_ret[80];
	char u_send_buf[1500];
	char u_send_buf1[MAX_BUF];
	char *u_send_ptr1=NULL;
	memset(u_send_buf,0x0,MAX_BUF);
	memset(u_send_buf1,0x0,MAX_BUF);	
        url_encode(format, format_ret, strlen(format_ret));

	p=pub_head;

        set_send_message(pub_session,pub_head,u_send_buf,u_send_buf1,u_send_ptr1,pub_max_count,pub_file_ptr,pub_present_path,pub_print,format);
	p=pub_head;
        while(p=p->Next) {
                p->data.filename[strlen(p->data.filename)]='\0';
        }
        p=pub_head;
        if(send(*file_queue[0].sendsock,u_send_buf,strlen(u_send_buf),0)==-1)
        {
                 error_handling("cm_sendsock error!!");
        }
        if(send(*file_queue[0].sendsock,u_send_buf1,strlen(u_send_buf1),0)==-1)
        {
                 error_handling("cm_sendsock error!!");
        }


	pub_tree_ptr = file_queue[0].tree_ptr;

*/
/* -----------------------------------------*/
        //order_queue(0,file_queue[0].cookie);
        //printf("\n%s\n",data_recv_buf);

        /*    */

        //printf("recv_ended\n");
}



void recv_success(int *data_sock) {
        char buf[MAX_BUF];
        memset(buf,0x0,MAX_BUF);

        snprintf(buf,MAX_BUF,"BYE 16777989\r\n");
	db_insert_file(&conn,user_id);

        if(send(*data_sock,buf,strlen(buf),0)==-1) {
                   error_handling("BYE recv success send() error!!");
        }

}
void recv_failed(int *data_sock) {
        char buf[MAX_BUF];
        memset(buf,0x0,MAX_BUF);

        snprintf(buf,MAX_BUF,"BYE 2164261683\r\n");

        if(send(*data_sock,buf,strlen(buf),0)==-1) {
                   error_handling("BYE recv failed send() error!!");
        }

}
